==> libunit-1.31.1.tgz: include/nxt_auto_config.h <==

#ifndef NXT_GCC
#define NXT_GCC  1
#endif


#define NXT_CONFIGURE_OPTIONS  " --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --pkgconfigdir=/usr/pkg/lib/pkgconfig --no-regex --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --log=/var/log/unit/unit.log --logdir=/var/log/unit --modulesdir=/usr/pkg/libexec/unit/modules --pid=/var/run/unit.pid --runstatedir=/var/run/unit --statedir=/var/db/unit --control=unix:/var/run/unit/control.unit.sock --tmpdir=/var/tmp --user=unit --group=unit --mandir=/usr/pkg/man --openssl"
#define NXT_SYSTEM_VERSION     "NetBSD 10.0 sparc64"
#define NXT_COMPILER_VERSION   "gcc version 10.5.0 (nb3 20231008) "

#define NXT_PID                "/var/run/unit.pid"
#define NXT_LOG                "/var/log/unit/unit.log"
#define NXT_MODULESDIR         "/usr/pkg/libexec/unit/modules"
#define NXT_STATEDIR           "/var/db/unit"
#define NXT_TMPDIR             "/var/tmp"

#define NXT_CONTROL_SOCK       "unix:/var/run/unit/control.unit.sock"

#define NXT_USER               "unit"
#define NXT_GROUP              "unit"


#ifndef NXT_UNIX
#define NXT_UNIX  1
#endif


#ifndef NXT_HAVE_UNIX_DOMAIN
#define NXT_HAVE_UNIX_DOMAIN  1
#endif


#ifndef NXT_HAVE_BIG_ENDIAN
#define NXT_HAVE_BIG_ENDIAN  1
#endif


#ifndef NXT_INT_SIZE
#define NXT_INT_SIZE  4
#endif


#ifndef NXT_LONG_SIZE
#define NXT_LONG_SIZE  8
#endif


#ifndef NXT_LONG_LONG_SIZE
#define NXT_LONG_LONG_SIZE  8
#endif


#ifndef NXT_PTR_SIZE
#define NXT_PTR_SIZE  8
#endif


#ifndef NXT_SIZE_T_SIZE
#define NXT_SIZE_T_SIZE  8
#endif


#ifndef NXT_OFF_T_SIZE
#define NXT_OFF_T_SIZE  8
#endif


#ifndef NXT_TIME_T_SIZE
#define NXT_TIME_T_SIZE  8
#endif


#ifndef NXT_HAVE_C99_VARIADIC_MACRO
#define NXT_HAVE_C99_VARIADIC_MACRO  1
#endif


#ifndef NXT_HAVE_BUILTIN_EXPECT
#define NXT_HAVE_BUILTIN_EXPECT  1
#endif


#ifndef NXT_HAVE_BUILTIN_UNREACHABLE
#define NXT_HAVE_BUILTIN_UNREACHABLE  1
#endif


#ifndef NXT_HAVE_BUILTIN_PREFETCH
#define NXT_HAVE_BUILTIN_PREFETCH  1
#endif


#ifndef NXT_HAVE_BUILTIN_CLZ
#define NXT_HAVE_BUILTIN_CLZ  1
#endif


#ifndef NXT_HAVE_BUILTIN_POPCOUNT
#define NXT_HAVE_BUILTIN_POPCOUNT  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_VISIBILITY
#define NXT_HAVE_GCC_ATTRIBUTE_VISIBILITY  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_ALIGNED
#define NXT_HAVE_GCC_ATTRIBUTE_ALIGNED  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_MALLOC
#define NXT_HAVE_GCC_ATTRIBUTE_MALLOC  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_PACKED
#define NXT_HAVE_GCC_ATTRIBUTE_PACKED  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_UNUSED
#define NXT_HAVE_GCC_ATTRIBUTE_UNUSED  1
#endif


#ifndef NXT_HAVE_GCC_ATOMIC
#define NXT_HAVE_GCC_ATOMIC  1
#endif


#ifndef NXT_HAVE_POSIX_MEMALIGN
#define NXT_HAVE_POSIX_MEMALIGN  1
#endif


#ifndef NXT_HAVE_ALLOCA
#define NXT_HAVE_ALLOCA  1
#endif


#ifndef NXT_HAVE_MAP_ANON
#define NXT_HAVE_MAP_ANON  1
#endif


#ifndef NXT_HAVE_SHM_OPEN
#define NXT_HAVE_SHM_OPEN  1
#endif


#ifndef NXT_HAVE_CLOCK_REALTIME
#define NXT_HAVE_CLOCK_REALTIME  1
#endif


#ifndef NXT_HAVE_CLOCK_MONOTONIC
#define NXT_HAVE_CLOCK_MONOTONIC  1
#endif


#ifndef NXT_HAVE_TM_GMTOFF
#define NXT_HAVE_TM_GMTOFF  1
#endif


#ifndef NXT_HAVE_LOCALTIME_R
#define NXT_HAVE_LOCALTIME_R  1
#endif


#ifndef NXT_HAVE_PTHREAD_SPINLOCK
#define NXT_HAVE_PTHREAD_SPINLOCK  1
#endif


#ifndef NXT_HAVE_SEM_TIMEDWAIT
#define NXT_HAVE_SEM_TIMEDWAIT  1
#endif


#ifndef NXT_HAVE_THREAD_STORAGE_CLASS
#define NXT_HAVE_THREAD_STORAGE_CLASS  1
#endif


#ifndef NXT_HAVE_KQUEUE
#define NXT_HAVE_KQUEUE  1
#endif


#ifndef NXT_HAVE_EVFILT_USER
#define NXT_HAVE_EVFILT_USER  1
#endif


#ifndef NXT_INET6
#define NXT_INET6  1
#endif


#ifndef NXT_SOCKADDR_SA_LEN
#define NXT_SOCKADDR_SA_LEN  1
#endif


#ifndef NXT_HAVE_SOCKADDR
#define NXT_HAVE_SOCKADDR  16
#endif


#ifndef NXT_HAVE_SOCKADDR_IN
#define NXT_HAVE_SOCKADDR_IN  16
#endif


#ifndef NXT_HAVE_SOCKADDR_IN6
#define NXT_HAVE_SOCKADDR_IN6  28
#endif


#ifndef NXT_HAVE_SOCKADDR_UN
#define NXT_HAVE_SOCKADDR_UN  106
#endif


#ifndef NXT_HAVE_SOCKADDR_STORAGE
#define NXT_HAVE_SOCKADDR_STORAGE  128
#endif


#ifndef NXT_HAVE_AF_UNIX_SOCK_SEQPACKET
#define NXT_HAVE_AF_UNIX_SOCK_SEQPACKET  1
#endif


#ifndef NXT_HAVE_MSGHDR_MSG_CONTROL
#define NXT_HAVE_MSGHDR_MSG_CONTROL  1
#endif


#ifndef NXT_HAVE_SYS_FILIO_H
#define NXT_HAVE_SYS_FILIO_H  1
#endif


#ifndef NXT_HAVE_FIONBIO
#define NXT_HAVE_FIONBIO  1
#endif


#ifndef NXT_HAVE_SOCK_NONBLOCK
#define NXT_HAVE_SOCK_NONBLOCK  1
#endif


#ifndef NXT_HAVE_ACCEPT4
#define NXT_HAVE_ACCEPT4  1
#endif


#ifndef NXT_HAVE_POSIX_FADVISE
#define NXT_HAVE_POSIX_FADVISE  1
#endif


#ifndef NXT_HAVE_GETRANDOM
#define NXT_HAVE_GETRANDOM  1
#endif


#ifndef NXT_HAVE_UCONTEXT
#define NXT_HAVE_UCONTEXT  1
#endif


#ifndef NXT_HAVE_DLOPEN
#define NXT_HAVE_DLOPEN  1
#endif


#ifndef NXT_HAVE_SETPROCTITLE
#define NXT_HAVE_SETPROCTITLE  1
#endif


#ifndef NXT_HAVE_GETGROUPLIST
#define NXT_HAVE_GETGROUPLIST  1
#endif


#ifndef NXT_NETBSD
#define NXT_NETBSD  1
#endif


#ifndef NXT_HAVE_OPENSSL
#define NXT_HAVE_OPENSSL  1
#endif


#ifndef NXT_HAVE_OPENSSL_VERSION
#define NXT_HAVE_OPENSSL_VERSION  "OpenSSL 3.0.12 24 Oct 2023"
#endif


#ifndef NXT_HAVE_OPENSSL_CONF_CMD
#define NXT_HAVE_OPENSSL_CONF_CMD  1
#endif


#ifndef NXT_HAVE_OPENSSL_TLSEXT
#define NXT_HAVE_OPENSSL_TLSEXT  1
#endif


#ifndef NXT_HAVE_UNMOUNT
#define NXT_HAVE_UNMOUNT  1
#endif


#ifndef NXT_DEBUG
#define NXT_DEBUG  0
#endif

#define NXT_SHM_PREFIX  "/"


#ifndef NXT_TLS
#define NXT_TLS  1
#endif

==> libunit-1.32.1.tgz: include/nxt_auto_config.h <==

#ifndef NXT_GCC
#define NXT_GCC  1
#endif


#define NXT_CONFIGURE_OPTIONS  " --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --pkgconfigdir=/usr/pkg/lib/pkgconfig --no-regex --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --log=/var/log/unit/unit.log --logdir=/var/log/unit --modulesdir=/usr/pkg/libexec/unit/modules --pid=/var/run/unit.pid --runstatedir=/var/run/unit --statedir=/var/db/unit --control=unix:/var/run/unit/control.unit.sock --tmpdir=/var/tmp --user=unit --group=unit --mandir=/usr/pkg/man --openssl"
#define NXT_SYSTEM_VERSION     "NetBSD 10.0 alpha"
#define NXT_COMPILER_VERSION   "gcc version 10.5.0 (nb3 20231008) "

#define NXT_PID                "/var/run/unit.pid"
#define NXT_LOG                "/var/log/unit/unit.log"
#define NXT_MODULESDIR         "/usr/pkg/libexec/unit/modules"
#define NXT_STATEDIR           "/var/db/unit"
#define NXT_TMPDIR             "/var/tmp"

#define NXT_CONTROL_SOCK       "unix:/var/run/unit/control.unit.sock"

#define NXT_USER               "unit"
#define NXT_GROUP              "unit"


#ifndef NXT_UNIX
#define NXT_UNIX  1
#endif


#ifndef NXT_HAVE_UNIX_DOMAIN
#define NXT_HAVE_UNIX_DOMAIN  1
#endif


#ifndef NXT_HAVE_LITTLE_ENDIAN
#define NXT_HAVE_LITTLE_ENDIAN  1
#endif


#ifndef NXT_INT_SIZE
#define NXT_INT_SIZE  4
#endif


#ifndef NXT_LONG_SIZE
#define NXT_LONG_SIZE  8
#endif


#ifndef NXT_LONG_LONG_SIZE
#define NXT_LONG_LONG_SIZE  8
#endif


#ifndef NXT_PTR_SIZE
#define NXT_PTR_SIZE  8
#endif


#ifndef NXT_SIZE_T_SIZE
#define NXT_SIZE_T_SIZE  8
#endif


#ifndef NXT_OFF_T_SIZE
#define NXT_OFF_T_SIZE  8
#endif


#ifndef NXT_TIME_T_SIZE
#define NXT_TIME_T_SIZE  8
#endif


#ifndef NXT_HAVE_C99_VARIADIC_MACRO
#define NXT_HAVE_C99_VARIADIC_MACRO  1
#endif


#ifndef NXT_HAVE_BUILTIN_EXPECT
#define NXT_HAVE_BUILTIN_EXPECT  1
#endif


#ifndef NXT_HAVE_BUILTIN_UNREACHABLE
#define NXT_HAVE_BUILTIN_UNREACHABLE  1
#endif


#ifndef NXT_HAVE_BUILTIN_PREFETCH
#define NXT_HAVE_BUILTIN_PREFETCH  1
#endif


#ifndef NXT_HAVE_BUILTIN_CLZ
#define NXT_HAVE_BUILTIN_CLZ  1
#endif


#ifndef NXT_HAVE_BUILTIN_POPCOUNT
#define NXT_HAVE_BUILTIN_POPCOUNT  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_VISIBILITY
#define NXT_HAVE_GCC_ATTRIBUTE_VISIBILITY  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_ALIGNED
#define NXT_HAVE_GCC_ATTRIBUTE_ALIGNED  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_MALLOC
#define NXT_HAVE_GCC_ATTRIBUTE_MALLOC  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_PACKED
#define NXT_HAVE_GCC_ATTRIBUTE_PACKED  1
#endif


#ifndef NXT_HAVE_GCC_ATTRIBUTE_UNUSED
#define NXT_HAVE_GCC_ATTRIBUTE_UNUSED  1
#endif


#ifndef NXT_HAVE_GCC_ATOMIC
#define NXT_HAVE_GCC_ATOMIC  1
#endif


#ifndef NXT_HAVE_POSIX_MEMALIGN
#define NXT_HAVE_POSIX_MEMALIGN  1
#endif


#ifndef NXT_HAVE_ALLOCA
#define NXT_HAVE_ALLOCA  1
#endif


#ifndef NXT_HAVE_MAP_ANON
#define NXT_HAVE_MAP_ANON  1
#endif


#ifndef NXT_HAVE_SHM_OPEN
#define NXT_HAVE_SHM_OPEN  1
#endif


#ifndef NXT_HAVE_CLOCK_REALTIME
#define NXT_HAVE_CLOCK_REALTIME  1
#endif


#ifndef NXT_HAVE_CLOCK_MONOTONIC
#define NXT_HAVE_CLOCK_MONOTONIC  1
#endif


#ifndef NXT_HAVE_TM_GMTOFF
#define NXT_HAVE_TM_GMTOFF  1
#endif


#ifndef NXT_HAVE_LOCALTIME_R
#define NXT_HAVE_LOCALTIME_R  1
#endif


#ifndef NXT_HAVE_PTHREAD_SPINLOCK
#define NXT_HAVE_PTHREAD_SPINLOCK  1
#endif


#ifndef NXT_HAVE_SEM_TIMEDWAIT
#define NXT_HAVE_SEM_TIMEDWAIT  1
#endif


#ifndef NXT_HAVE_THREAD_STORAGE_CLASS
#define NXT_HAVE_THREAD_STORAGE_CLASS  1
#endif


#ifndef NXT_HAVE_KQUEUE
#define NXT_HAVE_KQUEUE  1
#endif


#ifndef NXT_HAVE_EVFILT_USER
#define NXT_HAVE_EVFILT_USER  1
#endif


#ifndef NXT_INET6
#define NXT_INET6  1
#endif


#ifndef NXT_SOCKADDR_SA_LEN
#define NXT_SOCKADDR_SA_LEN  1
#endif


#ifndef NXT_HAVE_SOCKADDR
#define NXT_HAVE_SOCKADDR  16
#endif


#ifndef NXT_HAVE_SOCKADDR_IN
#define NXT_HAVE_SOCKADDR_IN  16
#endif


#ifndef NXT_HAVE_SOCKADDR_IN6
#define NXT_HAVE_SOCKADDR_IN6  28
#endif


#ifndef NXT_HAVE_SOCKADDR_UN
#define NXT_HAVE_SOCKADDR_UN  106
#endif


#ifndef NXT_HAVE_SOCKADDR_STORAGE
#define NXT_HAVE_SOCKADDR_STORAGE  128
#endif


#ifndef NXT_HAVE_AF_UNIX_SOCK_SEQPACKET
#define NXT_HAVE_AF_UNIX_SOCK_SEQPACKET  1
#endif


#ifndef NXT_HAVE_MSGHDR_MSG_CONTROL
#define NXT_HAVE_MSGHDR_MSG_CONTROL  1
#endif


#ifndef NXT_HAVE_SYS_FILIO_H
#define NXT_HAVE_SYS_FILIO_H  1
#endif


#ifndef NXT_HAVE_FIONBIO
#define NXT_HAVE_FIONBIO  1
#endif


#ifndef NXT_HAVE_SOCK_NONBLOCK
#define NXT_HAVE_SOCK_NONBLOCK  1
#endif


#ifndef NXT_HAVE_ACCEPT4
#define NXT_HAVE_ACCEPT4  1
#endif


#ifndef NXT_HAVE_POSIX_FADVISE
#define NXT_HAVE_POSIX_FADVISE  1
#endif


#ifndef NXT_HAVE_GETRANDOM
#define NXT_HAVE_GETRANDOM  1
#endif


#ifndef NXT_HAVE_UCONTEXT
#define NXT_HAVE_UCONTEXT  1
#endif


#ifndef NXT_HAVE_DLOPEN
#define NXT_HAVE_DLOPEN  1
#endif


#ifndef NXT_HAVE_SETPROCTITLE
#define NXT_HAVE_SETPROCTITLE  1
#endif


#ifndef NXT_HAVE_GETGROUPLIST
#define NXT_HAVE_GETGROUPLIST  1
#endif


#ifndef NXT_NETBSD
#define NXT_NETBSD  1
#endif


#ifndef NXT_HAVE_OPENSSL
#define NXT_HAVE_OPENSSL  1
#endif


#ifndef NXT_HAVE_OPENSSL_VERSION
#define NXT_HAVE_OPENSSL_VERSION  "OpenSSL 3.0.12 24 Oct 2023"
#endif


#ifndef NXT_HAVE_OPENSSL_CONF_CMD
#define NXT_HAVE_OPENSSL_CONF_CMD  1
#endif


#ifndef NXT_HAVE_OPENSSL_TLSEXT
#define NXT_HAVE_OPENSSL_TLSEXT  1
#endif


#ifndef NXT_HAVE_UNMOUNT
#define NXT_HAVE_UNMOUNT  1
#endif


#ifndef NXT_DEBUG
#define NXT_DEBUG  0
#endif

#define NXT_SHM_PREFIX  "/"


#ifndef NXT_TLS
#define NXT_TLS  1
#endif
